tabloc = {
  locked : {},
  isLocked : function(tabId) {
    return tabloc.locked["locked_" + tabId];
  },
  setLocked : function(tabId, value) {
    if(value){
      tabloc.locked["locked_" + tabId] = value;
    }else{
      delete tabloc.locked["locked_" + tabId];
    }
  },
  lockTab : function(tabId) {
    var options = tabloc.getOptions();
    options.command = "lockTab";
    chrome.tabs.sendMessage(tabId, options, function(response){
      if(response.result == "ok"){
        tabloc.setLocked(tabId, true);
        chrome.browserAction.setIcon({
          path: options.icon_path,
          tabId: tabId
        });
      }
    });
  },
  unlockTab : function(tabId) {
    chrome.tabs.sendMessage(tabId, {command: "unlockTab"}, function(response){
      if(response.result == "ok"){
        tabloc.setLocked(tabId, false);
        chrome.browserAction.setIcon({
          path: tabloc_options.get("ic_disabled"),
          tabId: tabId
        });
      }
    });
  },
  getOptions : function() {
    var fg_foreground = tabloc_options.get("fg_foreground");
    var icon_path;
    if (fg_foreground) {
      icon_path = tabloc_options.get("ic_foreground");
    } else {
      icon_path = tabloc_options.get("ic_background");
    }
    return {
      fg_foreground: tabloc_options.get("fg_foreground"),
      ex_inpagelink: tabloc_options.get("ex_inpagelink"),
      ex_javascript: tabloc_options.get("ex_javascript"),
      ex_formsubmit: tabloc_options.get("ex_formsubmit"),
      icon_path: icon_path
    };
  }
};

chrome.browserAction.onClicked.addListener(function(tab){
  if(! tabloc.isLocked(tab.id)){
    tabloc.lockTab(tab.id);
  }else{
    tabloc.unlockTab(tab.id);
  }
});

chrome.tabs.onUpdated.addListener(function(tabId, changeInfo, tab) {
  if(tabloc.isLocked(tabId)){
    return;
  }
  if(changeInfo.status == "loading"){
    chrome.browserAction.setIcon({
      path: tabloc_options.get("ic_disabled"),
      tabId: tabId
    });
  }
  var url = tab.url;
  var arr = tabloc_options.get("auto_url").split("\n");
  for(var i=0; i<arr.length; i++){
    if(url.match("^" + arr[i] + "$")){
      tabloc.lockTab(tabId);
      return;
    }
  }
  chrome.browserAction.setIcon({
    path: tabloc_options.get("ic_disabled"),
    tabId: tabId
  });
});

chrome.runtime.onMessage.addListener(
  function(message, sender, sendResponse) {
    if (message.command == "createTab") {
      if(tabloc_options.get("pos_relative")){
        chrome.tabs.getSelected(null, function(tab){
          chrome.tabs.create({
            url: message.url,
            selected: message.selected,
            index: tab.index + 1
          });
        });
      }else{
        chrome.tabs.create({
          url: message.url,
          selected: message.selected
        });
      }
      sendResponse({result: "ok"});
    }else{
      sendResponse({});
    }
  }
);
